function [struth, sdetections] = projectsitesplit(truth, detections)
% [struth, sdetections] = projectsitesplit(truth, detections)
% Given annotation sets truth and detections
% split these apart into structure arrays such that each
% entry struth(idx) or sdetections(idx) comes from a unique
% project and site.  Corresponding entries of struth and sdetections
% will be from the same project and site.
%
% See also:  read_annotations

narginchk(2,2);

delimiter = '|';  % Assume we won't use this in project/site names

% Find unique combinations of project and site
venues = unique(...
    [strcat(detections.project, delimiter, detections.site);
     strcat(truth.project, delimiter, truth.site)]);

% for each one, pull out the detections that correspond to it.
for vidx = 1:length(venues)
    % Find projects and sites
    projectsite = strsplit(venues{vidx}, delimiter);

    struth(vidx) = restrictdetections(projectsite{1}, projectsite{2}, truth);
    sdetections(vidx) = restrictdetections(projectsite{1}, projectsite{2}, detections);
    
end




