function tests = unittests
% Run unittests as follows:  runtests('unittests.m')
% Run unit tests to verify functionality

tests = functiontests(localfunctions)
end

function testMerge(testCase)
    %  5 rows with start and ends representing the following times:
    %  --------------------------
    %       ------------
    %            --------------------
    %                                    ----
    %                                          -------------
    %                                                    ------------
    %  Time axis --->
    % Returns
    %  3 rows with non-overlapping times
    %  -------------------------------
    %                                    ----
    %                                          ----------------------
    values = [
        0, 20
        4, 10
        7, 25
        30, 35,
        40, 50,
        45, 55];
    merged = merge(values);
    verifyEqual(testCase, [
         0 25
        30 35
        40 55], merged);
end

function testPerfect(testCase)
    % Compare file to itself and make sure everything looks good
      files = {'tests/hf-CINMS-C.csv', 'tests/lf-DCPP-A.csv'};
    for idx=1:length(files)
        r = dclde2018score(files{idx}, files{idx});
        verifyEqual(testCase, r.precision, 1);
        verifyEqual(testCase, r.recall, 1);
        verifyEqual(testCase, r.detectionCoverageOverallPct, 1);
        verifyEqual(testCase, r.truthCoverageOverallPct, 1);
        verifyEqual(testCase, sum(r.detectionCoveragePct), length(r.detectionCoverage));
        verifyEqual(testCase, sum(r.truthCoveragePct), length(r.truthCoverage));
    end
  
        
end

function testReduce50(testCase)
    % Compare a file to one where the coverage is reduced by 50%
    files = {'tests/hf-CINMS-C.csv', 'tests/lf-DCPP-A.csv'};
    for idx=1:length(files)
        truth = read_annotations(files{idx});
        detections = truth;
        % move detection start randomly 
        % gt |------------------------------|
        %    |--------------|
        % or           |--------------|
        % or                |---------------|
        shiftstart = randi(3, detections.N, 1) - 1;  % 0, 1, 2
        detections.start = detections.start + ...
            shiftstart .* detections.durations ./ 4;
        detections.end = detections.start + detections.durations ./ 2;
        detections.durations = detections.end - detections.start;

        
        r = dclde2018score(truth, detections);
        1;
        verifyEqual(testCase, r.precision, 1);
        verifyEqual(testCase, r.recall, 1);
        verifyEqual(testCase, r.detectionCoverageOverallPct, 1, 'RelTol', 0.001);
        verifyEqual(testCase, r.truthCoverageOverallPct, .5, 'RelTol', 0.001);
        verifyEqual(testCase, ...
            r.detectionCoveragePct, ones(size(r.detectionCoverage)), ...
            'RelTol', 0.01);
        verifyEqual(testCase, ...
            r.truthCoveragePct, .5*ones(size(r.truthCoveragePct)), ...
            'RelTol', 0.01);
        
    end
end

function testMergesplit(testCase)
    testdir = fullfile('tests', 'hf');
    % Assumes these files are sorted by project then site
    files = cellfun(@(fname) fullfile(testdir, fname), ...
        {'CINMS-B.csv', 'CINMS-C.csv', 'DCPP-A.csv'}, ...
        'UniformOutput', false);
    
    % Read everything together
    merged = read_annotations(files);
    % Split them by site and project
    [splits1, splits2] = projectsitesplit(merged, merged);
    for idx = 1:length(files)
        indiv = read_annotations(files{idx});
        fields = fieldnames(indiv);
        for fidx = 1:length(fields)
            verifyEqual(testCase, ...
                splits1(idx).(fields{fidx}), indiv.(fields{fidx}));
        end
    end
end
    
